<?php
/**
 * Le contenu
 * @author 		neolao <neo@neolao.com>
 */
class Content {
	/**
	 * L'identifiant de la page
	 * @var string
	 */
	public $id = "";
	/**
	 * Le contenu html
	 * @var string
	 */
	public $output = "";
	
	// ============================== CONSTRUCTOR ==============================
	/**
	 * Constructeur
	 */
	function Content(){
		$this->_getId();
		$this->_getContent();
	}
	
	// ================================ PRIVATE ================================
	/**
	 * Récupération de l'identifiant de la page
	 * @return string L'identifiant de la page
	 */
	private function _getId(){
		if(!empty($_POST["id"])){
			// Identifiant passé en POST
			$this->id = $_POST["id"];
		}else if(!empty($_GET["id"])){
			// Identifiant passé en GET
			$this->id = $_GET["id"];
		}else{
			// Aucune variable, on est à la home
			$this->id = "home";
		}
		return $this->id;
	}
	/**
	 * Récupérer le contenu
	 */
	private function _getContent(){
		switch($this->id){
			case "home":
				$this->output = $this->_contentHome();
				break;
			case "admin":
				$this->output = $this->_contentAdmin();
				break;
			case "update":
				$this->output = $this->_contentUpdate();
				break;
			case "warning":
				$this->output = $this->_contentWarning();
				break;
			case "help":
				$this->output = $this->_contentHelp();
				break;
		}

	}
	/**
	 * Le contenu de la home
	 * @return string Le contenu
	 */
	private function _contentHome(){
		global $lang;
		$o = "";
		
		// Titre
		$text = $lang->get("home", "title");
		if(!empty($text)){
			$o .= "<h2>".$text."</h2>\n";
		}
		
		// Intro
		$text = $lang->get("home", "intro");
		if(!empty($text)){
			$o .= "<p>".$text."</p>\n";
		}
		
		return $o;
	}
	/**
	 * Le contenu de l'admin
	 * @return string Le contenu
	 */
	private function _contentAdmin(){
		global $lang;
		$o = "";
		
		// Titre
		$text = $lang->get("admin", "title");
		if(!empty($text)){
			$o .= "<h2>".$text."</h2>\n";
		}
		
		// Intro
		$text = $lang->get("admin", "intro");
		if(!empty($text)){
			$o .= "<p>".$text."</p>\n";
		}
		
		return $o;
	}
	/**
	 * Le contenu des mises à jour
	 * @return string Le contenu
	 */
	private function _contentUpdate(){
		global $updates, $lang;
		$o = "";
		$empty = true;
		
		// Titre
		$text = $lang->get("update", "title");
		if(!empty($text)){
			$o .= "<h2>".$text."</h2>\n";
		}
		
		// Chaque mise à jour
		for($i=0; $i<count($updates); $i++){
			// Vérification
			$updates[$i]->check();
			
			// Si le formulaire est envoyé, on lance la mise à jour
			if($_POST["action"] == "update"){
				$updates[$i]->update();
				// On relance une vérification
				$updates[$i]->check();
			}
			
			// Affichage des fichiers à modifier
			if(version_compare($updates[$i]->getCurrentVersion(), $updates[$i]->getLatestVersion(), "<")){
				$o .= "<h3>".$updates[$i]->getTitle()."</h3>";
				$o .= "<p>".$lang->get("update", "latestVersion")." : ".$updates[$i]->getLatestVersion()." <em>(".$lang->get("update", "currentVersion")." : ".$updates[$i]->getCurrentVersion().")</em></p>";
				$o .= "<p>".$lang->get("update", "message")." : </p>";
				$o .= "<ul>";
				$listNewFiles = $updates[$i]->getNewFiles();
				for($j=0; $j<count($listNewFiles); $j++){
					$o .= "<li>".$listNewFiles[$j]["target"]."</li>";
				}
				$o .= "</ul>";
				$empty = false;
			}
		}
		
		
		// On affiche un formulaire pour mettre à jour s'il y a quelque chose
		if(!$empty){
			$form = new Form();
			$form->addHidden("id", "update");
			$form->addHidden("action", "update");
			$form->setSubmit($lang->get("general", "update"));
			$o .= $form->html();
		}
		
		return $o;
	}
	/**
	 * Le contenu des avertissements
	 * @return string Le contenu
	 */
	private function _contentWarning(){
		global $lang;
		$o = "";
		
		// Titre
		$text = $lang->get("warning", "title");
		if(!empty($text)){
			$o .= "<h2>".$text."</h2>\n";
		}
		
		return $o;
	}
	/**
	 * Le contenu de l'aide
	 * @return string Le contenu
	 */
	private function _contentHelp(){
		global $lang;
		$o = "";
		
		// Titre
		$text = $lang->get("help", "title");
		if(!empty($text)){
			$o .= "<h2>".$text."</h2>\n";
		}
		$o .= $lang->get("help", "content");
		
		return $o;
	}
	/**
	 * Aller à une page
	 * @param string $url L'url de destination
	 */
	private function _location($url){
		header("Location:".$url);
		exit;
	}
	// ================================ PUBLIC =================================
	/**
	 * Le contenu
	 * @return string Un affichage html
	 */
	public function html(){
		return $this->output;
	}
}
?>