<?php
/**
 * Création d'un formulaire
 * @author 		neolao <neo@neolao.com>
 */
class Form{
	/**
	 * Le contenu du formulaire
	 */
	private $_output;
	/**
	 * L'url de destination du formulaire
	 */
	private $_url;
	/**
	 * La méthode utilisée
	 */
	private $_method;
	/**
	 * L'identifiant du formulaire
	 */
	private $_id;
	/**
	 * Liste des champs cachés
	 */
	private $_hiddeninputs;
	/**
	 * Indique s'il y a un envoi de fichier
	 */
	private $_sendFile;
	/**
	 * Le texte du submit
	 */
	private $_submit;
	
	// ============================== CONSTRUCTOR ==============================
	/**
	 * Constructeur
	 * @param $url [optional] L'url de destination du formulaire
	 * @param $method [optional] La méthode utilisée
	 * @param $id [optional] L'identifiant du formulaire
	 */
	function Form($url=null, $method="post", $id=null){
		$this->_url = ($url != null)?$url:$_SERVER["PHP_SELF"];
		$this->_method = (strtolower($method) == "get")?"get":"post";
		$this->_id = $id;
		$this->_output = "";
		$this->_hiddeninputs = array();
		$this->_sendFile = false;
	}
	// ================================ PRIVATE ================================


	// ================================ PUBLIC =================================
	/**
	 * Ajoute un champ invisible
	 * @param $name Le nom
	 * @param $value La valeur
	 */
	public function addHidden($name, $value){
		array_push($this->_hiddeninputs, "<input type=\"hidden\" name=\"".$name."\" value=\"".$value."\" />");
	}
	/**
	 * Ajoute un paragraphe
	 * @param $text Le texte
	 */
	public function addParagraph($text){
		$this->_output .= "<p>".$text."</p>\n";
	}
	/**
	 * Ajoute un text
	 * @param $name Le nom
	 * @param $text [optional] Le contenu
	 * @param $id [optional] L'identifiant
	 */
	public function addText($name, $text="", $id=null){
		$this->_output .= "<p><input type=\"text\" name=\"".$name."\" value=\"".$text."\"";
		if(is_string($id)){
			$this->_output .= " id=\"".$id."\"";
		}
		$this->_output .= " /></p>\n";
	}
	/**
	 * Ajoute un textarea
	 * @param $name Le nom
	 * @param $cols La largeur
	 * @param $rows Le nombre de lignes
	 * @param $text [optional] Le contenu
	 * @param $id [optional] L'identifiant
	 */
	public function addTextArea($name, $cols, $rows, $text="", $id=null){
		$this->_output .= "<p><textarea name=\"".$name."\" cols=\"".$cols."\" rows=\"".$rows."\"";
		if(is_string($id)){
			$this->_output .= " id=\"".$id."\"";
		}
		$this->_output .= ">";
		$this->_output .= $text;
		$this->_output .= "</textarea></p>\n";
	}
	/**
	 * Ajoute un champ de type Parcourir
	 * @param $name Le nom
	 * @param $id [optional] L'identifiant
	 */
	public function addFile($name, $id=null){
		$this->_output .= "<p><input type=\"file\" name=\"".$name."\"";
		if(is_string($id)){
			$this->_output .= " id=\"".$id."\"";
		}
		$this->_output .= " /></p>\n";
		
		$this->_sendFile = true;
	}
	/**
	 * Ajoute des boutons radio
	 * @param $name Le nom
	 * @param $values La valeur
	 * @param $labels Le titre
	 * @param $check [optional] Celui qu'il faut sélectionner
	 */
	public function addRadioButtons($name, $values, $labels, $check=null){
		$this->_output .= "<ul>";
		for($i=0; $i<count($values); $i++){
			$this->_output .= "<li><input type=\"radio\" name=\"".$name."\" value=\"".$values[$i]."\"";
			if($values[$i] == $check){
				$this->_output .= " checked=\"checked\"";
			}
			$this->_output .= " /> ".$labels[$i]."</li>";
		}
		$this->_output .= "</ul>";
	}
	/**
	 * Ajoute une case à cocher
	 * @param $name Le nom
	 * @param $label Le titre
	 * @param $check Indique si la case est cochée par défaut
	 * @param $id [optional] L'identifiant
	 */
	public function addCheckbox($name, $label, $check=false, $id=null){
		$this->_output .= "<p><input type=\"checkbox\" name=\"".$name."\"";
		if($check){
			$this->_output .= " checked=\"checked\"";
		}
		if(is_string($id)){
			$this->_output .= " id=\"".$id."\"";
		}
		$this->_output .= "/>";
		$this->_output .= $label."</p>";
	}
	/**
	 * Modifie le texte du submit
	 * @param $name Le nom
	 */
	public function setSubmit($name){
		$this->_submit = $name;
	}
	/**
	 * Retourne l'affichage html
	 * @return string L'affichage html
	 */
	public function html(){
		// Début du formulaire
		$output = "\n<form method=\"".$this->_method."\"";
		$output .= " action=\"".$this->_url."\"";
		if(is_string($this->_id)){
			$output .= " id=\"".$this->_id."\"";
		}
		if($this->_sendFile){
			$output .= " enctype=\"multipart/form-data\"";			
		}
		$output .= ">\n";
		
		// Les champs cachés
		if(!empty($this->_hiddeninputs)){
			$output .= "<p>\n";
			for($i=0; $i<count($this->_hiddeninputs); $i++){
				$output .= $this->_hiddeninputs[$i]."\n";
			}
			$output .= "</p>\n";
		}
		
		// Les autres champs
		$output .= $this->_output;
		
		// Fin du formulaire
		$output .= "<p><input type=\"submit\"";
		if(!empty($this->_submit)){
			$output .= " value=\"".$this->_submit."\"";
		}
		$output .= "/></p>";
		$output .= "</form>\n";
		return $output;
	}
}
?>