<?php
/**
 * La langue
 * @author 		neolao <neo@neolao.com>
 */
class Language {
	/**
	 * Le chemin du dossier des langues
	 */
	private $_path;
	/**
	 * La langue par défault
	 */
	private $_lang_default = "fr";
	/**
	 * La langue utilisée
	 */
	private $_lang;
	/**
	 * L'encodage des caractères
	 */
	private $_encoding = "UTF-8";
	/**
	 * Le contenu par défaut
	 */
	private $_texts_default;
	/**
	 * Le contenu
	 */
	private $_texts;
	
	// ============================== CONSTRUCTOR ==============================
	/**
	 * Constructeur
	 * @param $path Le chemin du dossier des langues
	 * @param $lang_default La langue par défaut
	 * @param $encoding L'encodage des caractères
	 */
	function Language($path, $lang_default=null, $encoding=null){
		$this->_path = $path;
		if(!empty($lang_default)){
			$this->_lang_default = $lang_default;
			$this->_lang = $lang_default;
		}
		if(!empty($encoding)){
			$this->_encoding = $encoding;
		}
		$this->_checkLang();
	}
	
	// ================================ PRIVATE ================================
	/**
	 * Récupère le fichier de langue
	 */
	private function _checkLang(){
		global $error;
		$encoding = "";
		switch($this->_encoding){
			case "UTF-8":
				$encoding = "-utf8";
				break;
		}
		$this->_texts_default = @parse_ini_file($this->_path.$this->_lang_default.$encoding.".ini", TRUE);
		if(!$this->_texts_default){
			$error->add($this->_path.$this->_lang_default.$encoding.".ini");
		}
		$this->_texts = @parse_ini_file($this->_path.$this->_lang.$encoding.".ini", TRUE);
	}
	// ================================ PUBLIC =================================
	/**
	 * Change la langue
	 * @param $new_language La nouvelle langue
	 */
	public function setLang($new_language){
		$this->_lang = $new_language;
		$this->_checkLang();
	}
	/**
	 * Récupère la langue
	 */
	public function getLang(){
		return $this->_lang;
	}
	/**
	 * Récupère la langue
	 */
	public function getEncoding(){
		return $this->_encoding;
	}
	/**
	 * Récupère une traduction
	 * @param $category La catégorie de la traduction
	 * @param $text Le texte
	 */
	public function get($category, $text){
		$o = $this->_texts[$category][$text];
		if(is_null($o)){
			$o = $this->_texts_default[$category][$text];
		}
		return $o;
	}
}
?>