<?php
/**
 * Class abstraite pour la mise à jour
 * 
 * Par défaut, il y a un fichier config.ini dans le répertoire à mettre à jour, pour indiquer la version.
 * @author 		neolao <neo@neolao.com>
 */
abstract class AUpdate implements IUpdate{
	/**
	 * Le titre de la mettre à jour
	 * @var string
	 */
	protected $_title;
	/**
	 * Le répertoire à mettre à jour
	 * @var string
	 */
	protected $_dir;
	/**
	 * La version installée
	 * @var string
	 */
	protected $_currentVersion;
	/**
	 * La dernière version officielle
	 * @var string
	 */
	protected $_latestVersion;
	/**
	 * La liste des fichiers à mettre à jour
	 * @var array
	 */
	protected $_newFiles;
	
	// ============================== CONSTRUCTOR ==============================
	/**
	 * Constructeur
	 * @param string $title Le titre de la mise à jour
	 * @param string $directory Le chemin du répertoire à mettre à jour
	 */
	function __construct($title, $directory){
		$this->_title = $title;
		$this->_dir = realpath($directory);
	}
	// ================================ PRIVATE ================================
	
	// ================================ PUBLIC =================================
	/**
	 * Le titre de la mettre à jour
	 * @return Le titre
	 */
	public function getTitle(){
		return $this->_title;
	}
	/**
	 * Le titre de la mettre à jour
	 * @param string $title Le titre
	 */
	public function setTitle($title){
		$this->_title = $title;
	}
	/**
	 * Le répertoire à mettre à jour
	 * @return Le répêrtoire
	 */
	public function getDirectory(){
		return $this->_dir;
	}
	/**
	 * Le répertoire à mettre à jour
	 * @param string $directory Le répertoire
	 */
	public function setDirectory($directory){
		$this->_dir = $directory;
	}
	/**
	 * Récupération des informations utiles.
	 * C'est ici qu'on prépare la mise à jour
	 */
	public function check(){
		$config = parse_ini_file($this->_dir."/config.ini");
		$this->_currentVersion = $config["version"];
	}
	/**
	 * Récupèrè la version installée
	 * @return string La version installée
	 */
	public function getCurrentVersion(){
		return $this->_currentVersion;
	}
	/**
	 * Récupère la dernière version officielle
	 * @return string La dernière version officielle
	 */
	public function getLatestVersion(){
		return $this->_latestVersion;
	}
	/**
	 * Récupère la liste des fichiers à mettre à jour
	 * @return array La liste des fichiers à mettre à jour
	 */
	public function getNewFiles(){
		return $this->_newFiles;
	}
	/**
	 * Met à jour
	 */
	public function update(){
		global $error, $lang;
		$ok = true;
		
		// On vérifie les droits d'écriture
		for($i=0; $i<count($this->_newFiles); $i++){
			if(!is_writable($this->_newFiles[$i]["target"])){
				$error->add($lang->get("warning", "write")." : ".$this->_newFiles[$i]["target"]);
				$ok = false;
			}
		}
		
		// On fait la mise à jour si c'est ok
		if($ok){
			for($i=0; $i<count($this->_newFiles); $i++){
				if($sourceFile = @fopen($this->_newFiles[$i]["src"], "r")){
					$sourceContent = "";
					while(!feof($sourceFile)){
						$sourceContent .= fgets($sourceFile, 4096);
					}
					fclose($sourceFile);
					if($localFile = @fopen($this->_newFiles[$i]["target"], "w")){
						fwrite($localFile, $sourceContent);
						fclose($localFile);
					}else{
						$error->add($lang->get("warning", "write")." : ".$this->_newFiles[$i]["target"]);
					}
				}else{
					$error->add($lang->get("warning", "read")." : ".$this->_newFiles[$i]["src"]);
				}
			}
		}
	}
}
?>