<?php
/**
 * Mise à jour à partir d'un XML
 * 
 * On vérifie le contenu du XML. On récupère donc la dernière version officielle.
 * On peut aussi lister les fichiers modifiés depuis la version installée.
 * L'avantage, c'est de ne mettre à jour que les fichiers qui ont changés, pas la totalité.
 * @author 		neolao <neo@neolao.com>
 */
class UpdateFromXML extends AUpdate{
	/**
	 * L'url du XML
	 * @var string
	 */
	protected $_xmlUrl;
	/**
	 * Le XML
	 * @var SimpleXMLElement
	 */
	protected $_xml;
	
	// ============================== CONSTRUCTOR ==============================
	/**
	 * Constructeur
	 * @param string $title Le titre de la mise à jour
	 * @param string $directory Le chemin du répertoire à mettre à jour
	 * @param string $xmlUrl L'url du xml contenant le détail des mises à jour
	 */
	function __construct($title, $directory, $xmlUrl){
		parent::__construct($title, $directory);
		$this->_xmlUrl = $xmlUrl;
	}
	// ================================ PRIVATE ================================
	/**
	 * Récupération du XML
	 */
	protected function _getXML(){
		global $error, $lang;
		
		if($xmlFile = @fopen($this->_xmlUrl, "r")){
			$buffer = "";
			while(!feof($xmlFile)){
				$buffer .= fgets($xmlFile, 4096);
			}
			$this->_xml = simplexml_load_string($buffer);
		}else{
			$error->add($lang->get("warning", "read")." : ".$this->_xmlUrl);
		}
	}
	/**
	 * Récupération de la dernière version
	 */
	protected function _getLatestVersion(){
		if(!empty($this->_xml)){
			$this->_latestVersion = $this->_xml["version"];
		}
	}
	/**
	 * Récupération de la liste des fichiers à mettre à jour
	 */
	protected function _getNewFiles(){
		$target = array();
		$version = array();
		$this->_newFiles = array();
		if(!empty($this->_xml)){
			foreach ($this->_xml->children() as $release){
				if(version_compare($release["version"], $this->_currentVersion, ">")){
					foreach ($release->children() as $file){
						// On prépare la variable à lister
						$newFile = array();
						$newFile["target"] = $this->_dir."/".$file["target"];
						$newFile["src"] = (string)$file["src"];
						
						// On vérifie si la cible n'a pas déjà été listée
						$key = array_search($newFile["target"], $target);
						if($key !== false){
							// La cible a déjà été listée
							if(version_compare($release["version"], $version[$key], ">")){
								// Cette version est plus récente que celle listée
								$version[$key] = $release["version"];
								$this->_newFiles[$key]["src"] = $newFile["src"];
							}
						}else{
							// La cible n'a pas encore été listée, on le fait
							array_push($target, $newFile["target"]);
							array_push($version, $release["version"]);
							
							array_push($this->_newFiles, $newFile);
						}
					}
				}
			}
		}
	}
	
	// ================================ PUBLIC =================================
	/**
	 * Le titre de la mettre à jour
	 * @return Le titre
	 */
	public function getTitle(){
		return parent::getTitle();
	}
	/**
	 * Le titre de la mettre à jour
	 * @param string $title Le titre
	 */
	public function setTitle($title){
		parent::setTitle($title);
	}
	/**
	 * Le répertoire à mettre à jour
	 * @return Le répêrtoire
	 */
	public function getDirectory(){
		return parent::getDirectory();
	}
	/**
	 * Le répertoire à mettre à jour
	 * @param string $directory Le répertoire
	 */
	public function setDirectory($directory){
		parent::setDirectory($directory);
	}
	/**
	 * Récupération des informations utiles.
	 * C'est ici qu'on prépare la mise à jour
	 */
	public function check(){
		// Récupération de la version installée
		parent::check();
		
		// Récupération du contenu du XML
		$this->_getXML();
			
		// La dernière version officielle
		$this->_getLatestVersion();
		
		// La liste des fichiers à mettre à jour
		$this->_getNewFiles();
	}
	/**
	 * Récupèrè la version installée
	 * @return string La version installée
	 */
	public function getCurrentVersion(){
		return parent::getCurrentVersion();
	}
	/**
	 * Récupère la dernière version officielle
	 * @return string La dernière version officielle
	 */
	public function getLatestVersion(){
		return parent::getLatestVersion();
	}
	/**
	 * Récupère la liste des fichiers à mettre à jour
	 * @return array La liste des fichiers à mettre à jour
	 */
	public function getNewFiles(){
		return parent::getNewFiles();
	}
	/**
	 * Met à jour
	 */
	public function update(){
		parent::update();
	}
}
?>