<?php
/**
 * Plugin Browser
 * @author 		neolao <neo@neolao.com>
 */
class Plugin_Browser extends APlugin{
	/**
	 * Le chemin du répertoire
	 */
	private $path;
	/**
	 * Les préférences
	 */
	private $_config;
	
	// ============================== CONSTRUCTOR ==============================
	/**
	 * Constructeur
	 */
	function Plugin_Browser(){
		parent::__construct();
	}
	
	// ================================ PRIVATE ================================
	/**
	 * Afficher l'explorateur
	 */
	private function _showBrowser(){
		// Préférences
		$config = parse_ini_file($this->dataPath."config.ini");
		
	    $list = array();
	    if($dir = @opendir($this->path)){
	    	while(($file = readdir($dir)) !== false){
	    		$row = array("isdir"=>is_file($this->path."/".$file), 
	    					"filenamelower"=>strtolower($file), 
	    					"filename"=>$file, 
	    					"path"=>realpath($this->path."/".$file));
	    		array_push($list, $row);
    		}
			closedir($dir);
			sort($list);
	    }else{
	    	$this->error->add($this->mainLang->get("warning", "read")." : ".$this->path);
	    }
	    
	    if(!empty($list)){
		    // tableau
		    $this->content->output .= "<table class=\"browser\">";
		    $this->content->output .= "<tr>";
			$this->content->output .= "<th>".$this->lang->get("home", "filename")."</th>";
			$this->content->output .= "<th>".$this->lang->get("home", "fileactions")."</th>";
			if($config["show_size"]){
				$this->content->output .= "<th>".$this->lang->get("home", "filesize")."</th>";
			}
			if($config["show_perms"]){
				$this->content->output .= "<th>".$this->lang->get("home", "fileperms")."</th>";
			}
			$this->content->output .= "<th>".$this->lang->get("home", "filetime")."</th>";
			$this->content->output .= "</tr>";
		    foreach($list as $value) {
		    	// On vérifie les droits
		    	if(is_readable($value["path"])){
	    			$this->content->output .= "<tr>";
		    	}else{
		    		$this->content->output .= "<tr class=\"notreadable\">";
		    	}
		    	
		    	// On vérifie le type
		    	if(is_dir($value["path"])){
					$this->content->output .= "<td class=\"folder\"><a href=\"".$_SERVER["PHP_SELF"]."?id=plugin:browser&amp;path=".realpath($value["path"])."\">".$value["filename"]."</a></td>";
		    	}else{
					$this->content->output .= "<td class=\"file\"><a href=\"".$_SERVER["PHP_SELF"]."?id=plugin:browser&amp;path=".$value["path"]."\">".$value["filename"]."</a></td>";
		    	}
		    	
		    	// Les actions
		    	$this->content->output .= "<td class=\"actions\">";
		    	if($value["filename"] == "."){
		    		// Si c'est le dossier courant
					// Ajouter un fichier
					$this->content->output .= "<a class=\"addfile\" href=\"".$_SERVER["PHP_SELF"]."?id=plugin:browser&amp;path=".$value["path"]."&amp;action=tryaddfile\">+FILE</a>";
					// Ajouter un dossier
					$this->content->output .= "<a class=\"addfolder\" href=\"".$_SERVER["PHP_SELF"]."?id=plugin:browser&amp;path=".$value["path"]."&amp;action=tryaddfolder\">+DIR</a>";
		    	}else if($value["filename"] == ".."){
		    		// Si c'est le dossier parent
		    		$this->content->output .= "-";
		    	}else if(is_dir($value["path"])){
		    		// Si c'est un dossier
					// Renommer
					$this->content->output .= "<a class=\"rename\" href=\"".$_SERVER["PHP_SELF"]."?id=plugin:browser&amp;path=".$value["path"]."&amp;action=tryrename\">REN</a>";
					// Effacer
					$this->content->output .= "<a class=\"delete\" href=\"".$_SERVER["PHP_SELF"]."?id=plugin:browser&amp;path=".$value["path"]."&amp;action=trydelete\">DEL</a>";
		    	}else{
		    		// Si c'est un fichier
					// Renommer
					$this->content->output .= "<a class=\"rename\" href=\"".$_SERVER["PHP_SELF"]."?id=plugin:browser&amp;path=".$value["path"]."&amp;action=tryrename\">REN</a>";
					// Effacer
					$this->content->output .= "<a class=\"delete\" href=\"".$_SERVER["PHP_SELF"]."?id=plugin:browser&amp;path=".$value["path"]."&amp;action=trydelete\">DEL</a>";
					// Editer en UTF-8
					$this->content->output .= "<a class=\"edit\" href=\"".$_SERVER["PHP_SELF"]."?id=plugin:browser&amp;path=".$value["path"]."&amp;encoding=UTF-8\">UTF-8</a>";
		    	}
				$this->content->output .= "</td>";
		    	
		    	if($config["show_size"]){
			    	// On vérifie la taille
			    	if(is_dir($value["path"])){
			    		$this->content->output .= "<td class=\"size\"> - </td>";
			    	}else{
			    		$this->content->output .= "<td class=\"size\">".@$this->_filesize($value["path"])."</td>";
			    	}
		    	}
		    	
		    	if($config["show_perms"]){
			    	// On vérifie les droits
			    	$this->content->output .= "<td class=\"perms\">".$this->_fileperms($value["path"])."</td>";
		    	}
		    	
		    	// On vérifie la date
		    	$this->content->output .= "<td>".@date('Y-m-d h:i:s', filemtime($value["path"]))."</td>";
		    	
				$this->content->output .= "</tr>";
		    }
		    $this->content->output .= "</table>";
	    }
	}
	/**
	 * Afficher le contenu d'un fichier
	 */
	private function _showContentFile(){
		$read_access = false;
		$write_access = false;
		$handle = @fopen($this->path, "a+");
		
		if($handle !== false){
			// Lecture et écriture
			$read_access = true;
			$write_access = true;
		}else{
			$handle = @fopen($this->path, "r");
			if($handle !== false){
				// Lecture seule
				$read_access = true;
			}else{
				$this->error->add($this->mainLang->get("warning", "read")." : ".$this->path);
			}
		}
		
		if($read_access){
			// Contenu
			$content = "";
			rewind($handle);
			while (!feof($handle)) {
				$content .= fgets($handle, 4096);
			}
			
			// Encodage
			$encoding = (isset($_REQUEST["encoding"]))?$_REQUEST["encoding"]:"ISO-8859-1";
			$this->content->output .= "<p>Encodage : ".$encoding."</p>";
		}
			
		if($write_access){
			// Formulaire
			$form = new Form();
			$form->addHidden("id", "plugin:browser");
			$form->addHidden("path", $this->path);
			$form->addHidden("action", "save");
			$form->addTextArea("content", "80", "10", htmlentities($content, ENT_COMPAT, $encoding));
			$form->addRadioButtons("encodingto", array("ISO-8859-1", "UTF-8"), array("ISO-8859-1", "UTF-8"), $encoding);
			$this->content->output .= $form->html();
			
			fclose($handle);
		}else if($read_access){
			// Affichage simple
			$this->content->output .= "<pre class=\"source\">".htmlentities($content, ENT_COMPAT, $encoding)."</pre>";
			
			fclose($handle);
		}
	}
	/**
	 * Affichage de la confirmation de renommage
	 */
	private function _showRenameConfirm(){
		// Formulaire
		$form = new Form();
		$form->addHidden("id", "plugin:browser");
		$form->addHidden("path", $this->path);
		$form->addHidden("action", "rename");
		$form->addParagraph($this->lang->get("home", "rename_message"));
		$form->addText("newname", basename($this->path));
		$this->content->output .= $form->html();
	}
	/**
	 * Affichage de la confirmation d'effacement
	 */
	private function _showDeleteConfirm(){
		// Formulaire
		$form = new Form();
		$form->addHidden("id", "plugin:browser");
		$form->addHidden("path", $this->path);
		$form->addHidden("action", "delete");
		$form->addParagraph($this->lang->get("home", "delete_message"));
		$this->content->output .= $form->html();
	}
	/**
	 * Affichage de l'ajout de fichier
	 */
	private function _showAddFile(){
		// Formulaire
		$form = new Form();
		$form->addHidden("id", "plugin:browser");
		$form->addHidden("path", $this->path);
		$form->addHidden("action", "addfile");
		$form->addParagraph($this->lang->get("home", "addfile_message"));
		$form->addfile("newfile");
		$form->addParagraph($this->lang->get("home", "addfile_message2"));
		$form->addText("newname");
		$this->content->output .= $form->html();
	}
	/**
	 * Affichage de l'ajout de dossier
	 */
	private function _showAddFolder(){
		// Formulaire
		$form = new Form();
		$form->addHidden("id", "plugin:browser");
		$form->addHidden("path", $this->path);
		$form->addHidden("action", "addfolder");
		$form->addParagraph($this->lang->get("home", "addfolder_message"));
		$form->addText("newname");
		$this->content->output .= $form->html();
	}
	/**
	 * Taille du fichier avec l'unité
	 * @param $path le chemin du fichier
	 * @return La taille du fichier
	 */
	private function _filesize($path){
		$coma = 2;
		$unit = "&nbsp;o";
		$octet = filesize($path);
		if($octet === false){
			return "-";
		}
		
		if($octet >= 1000){
			$octet /= 1000;
			$unit = "Ko";
		}
		if($octet >= 1000){
			$octet /= 1000;
			$unit = "Mo";
		}
		if($octet >= 1000){
			$octet /= 1000;
			$unit = "Go";
		}
		return round($octet, $coma)."&nbsp;".$unit;
	}
	/**
	 * Permissions du fichier
	 * @param $path le chemin du fichier
	 * @return Les permissions du fichier
	 */
	private function _fileperms($path){
		$perms = fileperms($path);

		if (($perms & 0xC000) == 0xC000) {
		    // Socket
		    $info = 's';
		} elseif (($perms & 0xA000) == 0xA000) {
		    // Lien symbolique
		    $info = 'l';
		} elseif (($perms & 0x8000) == 0x8000) {
		    // Régulier
		    $info = '-';
		} elseif (($perms & 0x6000) == 0x6000) {
		    // Block spécial
		    $info = 'b';
		} elseif (($perms & 0x4000) == 0x4000) {
		    // Dossier
		    $info = 'd';
		} elseif (($perms & 0x2000) == 0x2000) {
		    // Caractère spécial
		    $info = 'c';
		} elseif (($perms & 0x1000) == 0x1000) {
		    // FIFO pipe
		    $info = 'p';
		} else {
		    // Inconnu
		    $info = 'u';
		}
		
		// Propriétaire
		$info .= (($perms & 0x0100) ? 'r' : '-');
		$info .= (($perms & 0x0080) ? 'w' : '-');
		$info .= (($perms & 0x0040) ?
		            (($perms & 0x0800) ? 's' : 'x' ) :
		            (($perms & 0x0800) ? 'S' : '-'));
		
		// Groupe
		$info .= (($perms & 0x0020) ? 'r' : '-');
		$info .= (($perms & 0x0010) ? 'w' : '-');
		$info .= (($perms & 0x0008) ?
		            (($perms & 0x0400) ? 's' : 'x' ) :
		            (($perms & 0x0400) ? 'S' : '-'));
		
		// Tous
		$info .= (($perms & 0x0004) ? 'r' : '-');
		$info .= (($perms & 0x0002) ? 'w' : '-');
		$info .= (($perms & 0x0001) ?
		            (($perms & 0x0200) ? 't' : 'x' ) :
		            (($perms & 0x0200) ? 'T' : '-'));
		
		return $info;
	}
	/**
	 * Effacement récursif
	 * @param $path Le chemin
	 * @return true si l'opération s'est bien déroulée, sinon false
	 */
	private function _delete($path){
		if(is_file($path)){
			if(!unlink($path)){
				$this->error->add($this->mainLang->get("warning", "write")." : ".$path);
				return false;
			}
			return true;
		}else{
			if($dir = opendir($path)){
		    	while(($file = readdir($dir)) !== false){
		    		if(!in_array($file, array(".", ".."))){
			    		if(!$this->_delete($path."/".$file)){
			    			return false;
			    		}
		    		}
	    		}
				closedir($dir);
				if(!rmdir($path)){
					$this->error->add($this->mainLang->get("warning", "write")." : ".$path);
					return false;
				}
				return true;
		    }else{
		    	$this->error->add($this->mainLang->get("warning", "read")." : ".$path);
		    	return false;
		    }
		}
	}
	// ================================ PUBLIC =================================
	/**
	 * Initialisation
	 */
	public function init(){
		parent::init();
		
		// Fichier des préférences
		$this->_config = new DataText($this->dataPath."config.ini");
		
		// Remplissage par défaut s'il est vide
		$config = $this->_config->get();
		if(empty($config)){
			$config = "show_size = true\n";
			$config .= "show_perms = true\n";
			$this->_config->set($config);
		}
	}
	/**
	 * Traitement du formulaire
	 */
	public function checkForm(){
		$this->path = (isset($_GET["path"]))?$_GET["path"]:WM_BASE_PATH;
		
		// Renommage
		if(isset($_POST["path"]) && isset($_POST["newname"]) && $_POST["action"] == "rename"){
			$this->path = $_POST["path"];
			$folder = dirname($this->path);
			
			if(!@rename($this->path, $folder."/".$_POST["newname"])){
				$this->error->add($this->mainLang->get("warning", "write")." : ".$this->path);
			}
			$this->path = $folder;
		}
		
		// Effacement
		if(isset($_POST["path"]) && $_POST["action"] == "delete"){
			$this->path = $_POST["path"];
			$folder = dirname($this->path);
			
			
			if(!@$this->_delete($this->path)){
				$this->error->add($this->mainLang->get("warning", "write")." : ".$this->path);
			}
			$this->path = $folder;
		}
		
		// Ajout d'un fichier
		if(isset($_POST["path"]) && isset($_FILES["newfile"]) && isset($_POST["newname"]) && $_POST["action"] == "addfile"){
			$this->path = $_POST["path"];
			
			if(!empty($_FILES["newfile"]["tmp_name"])){
				// Il y a un envoi de fichier
				if(!empty($_POST["newname"])){
					// Il y a un nouveau nom
					if(!copy($_FILES["newfile"]["tmp_name"], $this->path."/".$_POST["newname"])){
						$this->error->add($this->mainLang->get("warning", "write")." : ".$this->path);
					}
				}else{
					// Garder le nom d'origine
					if(!copy($_FILES["newfile"]["tmp_name"], $this->path."/".$_FILES["newfile"]["name"])){
						$this->error->add($this->mainLang->get("warning", "write")." : ".$this->path);
					}
				}
			}else{
				// Il n'y a pas d'envoi de fichier
				if(!empty($_POST["newname"])){
					// Il faut créer un fichier vide
					if($handle = @fopen($this->path."/".$_POST["newname"], "a+")){
						fclose($handle);
					}else{
						$this->error->add($this->mainLang->get("warning", "write")." : ".$this->path);
					}
				}
			}

		}
											
		// Ajout d'un dossier
		if(isset($_POST["path"]) && isset($_POST["newname"]) && $_POST["action"] == "addfolder"){
			$this->path = $_POST["path"];

			if(!@mkdir($this->path."/".$_POST["newname"])){
				$this->error->add($this->mainLang->get("warning", "write")." : ".$this->path);
			}
		}
		
		// Edition
		if(isset($_POST["path"]) && isset($_POST["content"]) && isset($_POST["encodingto"]) && $_POST["action"] == "save"){
			$this->path = $_POST["path"];
			$content = $_POST["content"];
			if($this->lang->getEncoding() == "UTF-8" && $_POST["encodingto"] == "ISO-8859-1"){
				// L'encodage final est ISO alors que l'encodage du site est UTF-8
				$content = utf8_decode($content);
			}else if($this->lang->getEncoding() == "ISO-8859-1" && $_POST["encodingto"] == "UTF-8"){
				// L'encodage final est UTF-8 alors que l'encodage du site est ISO
				$content = utf8_encode($content);
			}
			
			// Supprimer les caractères d'échappement
			$content = str_replace(array("\\\"", "\\'", "\\\\"), array("\"", "'", "\\"), $content);
			
			if(is_writable($this->path)){
				if($handle = fopen($this->path, "w")){
					if(fwrite($handle, $content) === false){
						$this->error->add($this->mainLang->get("warning", "write")." : ".$this->path);
					}
					fclose($handle);
					$this->path = dirname($this->path);
				}else{
					$this->error->add($this->mainLang->get("warning", "read")." : ".$this->path);
				}
			}else{
				$this->error->add($this->mainLang->get("warning", "read")." : ".$this->path);
			}
		}
	}
	/**
	 * Exécuté lorsqu'on affiche la page d'accueil du plugin
	 */
	public function home(){
		$this->content->output = "<h2>".$this->lang->get("home", "title")."</h2>";
	    $this->content->output .= "<h3>".realpath($this->path)."</h3>";
		
		$action = $_REQUEST["action"];
		switch($action){
			case "tryrename":
				// Tentative de renommage
				$this->_showRenameConfirm();
				break;
			case "trydelete":
				// Tentative d'effacement
				$this->_showDeleteConfirm();
				break;
			case "tryaddfile":
				// Tentative d'ajout de fichier
				$this->_showAddFile();
				break;
			case "tryaddfolder":
				// Tentative d'ajout de dossier
				$this->_showAddFolder();
				break;
			default:
				// Comportement par défaut
				if(is_dir($this->path)){
					// Affichage de l'explorateur
					$this->_showBrowser();
				}else{
					// C'est un fichier
					$this->_showContentFile();
				}
		}
	}
	/**
	 * Administration
	 */
	public function admin(){
		// Traitement du formulaire
		if($_POST["plugin"] == "browser"){
			$config = "";
			$config .= ($_POST["show_size"] == "on")?"show_size = true":"show_size = false";
			$config .= "\n";
			$config .= ($_POST["show_perms"] == "on")?"show_perms = true":"show_perms = false";
			$config .= "\n";
			$this->_config->set($config);
		}
		
		$this->content->output .= "<h3>".$this->lang->get("home", "title")."</h3>";
		$config = parse_ini_file($this->dataPath."config.ini");
		
		// Formulaire
		$form = new Form();
		$form->addHidden("id", "admin");
		$form->addHidden("plugin", "browser");
		foreach($config as $key=>$value){
			$form->addCheckbox($key, $this->lang->get("admin", $key), $value);
		}
		$form->setSubmit($this->mainLang->get("general", "save"));
		$this->content->output .= $form->html();
		
	}
	/**
	 * Exécuté tout le temps
	 */
	public function main(){
		parent::main();
		
		
	}
}
?>