<?php
/**
 * Plugin DokuWiki Check
 * @author 		neolao <neo@neolao.com>
 */
class Plugin_DokuWikiCheck extends APlugin{
	/**
	 * Les données
	 */
	private $_data;
	
	// ============================== CONSTRUCTOR ==============================
	/**
	 * Constructeur
	 */
	function Plugin_DokuWikiCheck(){
		parent::__construct();
	}
	
	// ================================ PRIVATE ================================
	/**
	 * Récupération de la version officiel de DokuWiki
	 * @return La dernière version
	 */
	private function _check(){
		$url = "http://www.splitbrain.org/projects/dokuwiki";
		
		$fp = @fopen($url, "r");
		if($fp !== false){
			// Récupération du contenu de la page
			$content = "";
			while(!feof($fp)){
				$content .= fgets($fp, 4096);
			}
			fclose($fp);
			
			// Recherche de la dernière version
			preg_match_all("/dokuwiki\-([0-9\-]+)\.tgz/", $content, $matches);
			return $matches[1][0];
		}else{
			$this->error->add($this->lang->get("warning", "fail_check")." : ".$url);
			return false;
		}
	}
	// ================================ PUBLIC =================================
	/**
	 * Initialisation
	 */
	public function init(){
		parent::init();
		
		// Fichier des données
		$this->_data = new DataText($this->dataPath."datas.txt");
	}
	/**
	 * Traitement du formulaire
	 */
	public function checkForm(){
		if(isset($_POST["content"])){
			$this->_data->set(stripslashes($_POST["content"]));
		}
	}
	/**
	 * Exécuté lorsqu'on affiche la page d'accueil du plugin
	 */
	public function home(){			
		// Titre
		$this->content->output = "<h2>".$this->lang->get("home", "title")."</h2>";
		
		// Ma version
		$this->content->output .= "<h3>".$this->lang->get("home", "myVersion")."</h3>";
		
		// Formulaire
		$form = new Form();
		$form->addHidden("id", "plugin:dokuwiki_check");
		$form->addText("content", htmlentities($this->_data->get(), ENT_COMPAT, $this->lang->getEncoding()));
		$form->setSubmit($this->mainLang->get("general", "save"));
		$this->content->output .= $form->html();
		
		// La version officielle
		$this->content->output .= "<h3>".$this->lang->get("home", "latestVersion")."</h3>";
		$this->content->output .= "<p>".$this->_check()."</p>";
	}
	/**
	 * Avertissements
	 */
	public function warning(){
		$latest_version = $this->_check();
		if(!empty($latest_version)){
			$myVersion = $this->_data->get();
			if($myVersion < $latest_version){
				// Titre
				$this->content->output .= "<h3>".$this->lang->get("home", "title")."</h3>";
				
				// Avertissement
				$this->content->output .= "<p>".$this->lang->get("warning", "new_version")." : ".$latest_version."</p>";
			}
		}
	}
	/**
	 * Exécuté tout le temps
	 */
	public function main(){
		parent::main();
		
	}
}
?>