<?php
/**
 * Plugin Email
 * @author 		neolao <neo@neolao.com>
 */
class Plugin_Email extends APlugin{
	/**
	 * Les données
	 */
	private $_data;
	
	// ============================== CONSTRUCTOR ==============================
	/**
	 * Constructeur
	 */
	function Plugin_Email(){
		parent::__construct();
	}
	
	// ================================ PRIVATE ================================
	/**
	 * Affichage de la taille avec l'unité
	 * @param $octet La taille en octet
	 * @return La taille formatée
	 */
	private function _easySize($octet){
		$coma = 2;
		$unit = "&nbsp;o";
		
		if($octet >= 1000){
			$octet /= 1000;
			$unit = "Ko";
		}
		if($octet >= 1000){
			$octet /= 1000;
			$unit = "Mo";
		}
		if($octet >= 1000){
			$octet /= 1000;
			$unit = "Go";
		}
		return round($octet, $coma)."&nbsp;".$unit;
	}
	/**
	 * Vérification des données
	 * @return La liste des comptes courriel et leurs proprités
	 */
	private function _check(){
		$result = array();
		// Vérification des fonctions IMAP
		if(!function_exists("imap_open")){
			$this->error->add($this->lang->get("warning", "no_imap"));
			return $result;
		}
		
		// Récupération des données
		$content = split("\r?\n", trim($this->_data->get()));
		if(!empty($content) && !empty($content[0])){
			
			for($i=0; $i<count($content); $i++){
				list($account, $mailbox, $login, $pass, $quota) = split("\|", $content[$i]);
				$resource = @imap_open($mailbox, $login, $pass);
				if($resource === false){
					$this->error->add($this->lang->get("warning", "open_fail")." : ".$mailbox);
				}else{
					$infos = imap_mailboxmsginfo($resource);
					$row = array(account=>$account, 
								mailbox=>$mailbox, 
								login=>$login, 
								password=>$pass, 
								size=>$infos->Size, 
								quota=>$quota);
					array_push($result, $row);
					imap_close($resource);
				}
			}
		}
		return $result;
	}
	// ================================ PUBLIC =================================
	/**
	 * Initialisation
	 */
	public function init(){
		parent::init();
		
		// Fichier des données
		$this->_data = new DataText($this->dataPath."datas.txt");
	}
	/**
	 * Traitement du formulaire
	 */
	public function checkForm(){
		// Modification de la liste des comptes
		if(isset($_POST["content"])){
			$this->_data->set(stripslashes($_POST["content"]));
		}		
	}
	/**
	 * Exécuté lorsqu'on affiche la page d'accueil du plugin
	 */
	public function home(){
		// Titre
		$this->content->output = "<h2>".$this->lang->get("home", "title")."</h2>";
		
		// Les comptes
		$this->content->output .= "<h3>".$this->lang->get("home", "accounts")."</h3>";
		
		// Introduction
		$this->content->output .= "<p>".$this->lang->get("home", "accounts_intro")."</p>";
		
		// Formulaire
		$form = new Form();
		$form->addHidden("id", "plugin:email");
		$form->addTextArea("content", "80", "10", htmlentities($this->_data->get(), ENT_COMPAT, $this->lang->getEncoding()));
		$form->setSubmit($this->mainLang->get("general", "save"));
		$this->content->output .= $form->html();
		
		// Le détail des comptes
		$this->content->output .= "<h3>".$this->lang->get("home", "informations")."</h3>";
		
		// Formulaire
		$form = new Form();
		$form->addHidden("id", "plugin:email");
		$form->addHidden("action", "check");
		$form->setSubmit($this->mainLang->get("general", "show"));
		$this->content->output .= $form->html();
		
		// Affichage
		if($_POST["action"] == "check"){
			$list = $this->_check();
			if(!empty($list)){
				$this->content->output .= "<table>\n";
				$this->content->output .= "<tr><th>".$this->lang->get("home", "account")."</th><th>".$this->lang->get("home", "size")."</th></tr>";
				for($i=0; $i<count($list); $i++){
						$this->content->output .= "<tr>";
						$this->content->output .= "<td>".$list[$i]["account"]."</td>";
						$this->content->output .= "<td class=\"size\">".$this->_easySize($list[$i]["size"])."</td>";
						$this->content->output .= "</tr>";
				}
				$this->content->output .= "</table>\n";
			}
		}
		
	}
	/**
	 * Page d'aide
	 */
	public function help(){
		// Titre
		$this->content->output = "<h2>".$this->lang->get("help", "title")."</h2>";
		
		// Les comptes
		$this->content->output .= "<h3>".$this->lang->get("home", "accounts")."</h3>";
		
		// Exemples
		$this->content->output .= $this->lang->get("help", "content");
	}
	/**
	 * Avertissements
	 */
	public function warning(){
		$output = array();
		$list = $this->_check();
		if(!empty($list)){
			for($i=0; $i<count($list); $i++){
				if(!empty($list[$i]["quota"]) && $list[$i]["size"] > $list[$i]["quota"]){
					array_push($output, $this->lang->get("warning", "quota_limit").$list[$i]["account"]);
				}	
			}
		}
		
		if(!empty($output)){
			// Titre
			$this->content->output .= "<h3>".$this->lang->get("home", "title")."</h3>";
			
			// Liste des problèmes
			$this->content->output .= "<ul>";
			for($i=0; $i<count($output); $i++){
				$this->content->output .= "<li>".$output[$i]."</li>";
			}
			$this->content->output .= "</ul>";
		}
	}
	/**
	 * Exécuté tout le temps
	 */
	public function main(){
		parent::main();
		
		
	}
}
?>