<?php
/**
 * Plugin PunBB Check
 * @author 		neolao <neo@neolao.com>
 */
class Plugin_PunBBCheck extends APlugin{
	/**
	 * Les données
	 */
	private $_data;
	
	// ============================== CONSTRUCTOR ==============================
	/**
	 * Constructeur
	 */
	function Plugin_PunBBCheck(){
		parent::__construct();
	}
	
	// ================================ PRIVATE ================================
	/**
	 * Récupération de la version officiel de PunBB
	 * @return La dernière version
	 */
	private function _check(){
		$fp = @fopen("http://www.punbb.org/latest_version", "r");
		if($fp !== false){
			$latest_version = trim(fread($fp, 16));
			fclose($fp);
			return $latest_version;
		}else{
			$this->error->add($this->lang->get("warning", "fail_check")." : http://www.punbb.org/latest_version");
			return false;
		}
	}
	// ================================ PUBLIC =================================
	/**
	 * Initialisation
	 */
	public function init(){
		parent::init();
		
		// Fichier des données
		$this->_data = new DataText($this->dataPath."datas.txt");
	}
	/**
	 * Traitement du formulaire
	 */
	public function checkForm(){
		if(isset($_POST["content"])){
			$this->_data->set(stripslashes($_POST["content"]));
		}
	}
	/**
	 * Exécuté lorsqu'on affiche la page d'accueil du plugin
	 */
	public function home(){			
		// Titre
		$this->content->output = "<h2>".$this->lang->get("home", "title")."</h2>";
		
		// Ma version
		$this->content->output .= "<h3>".$this->lang->get("home", "myVersion")."</h3>";
		
		// Formulaire
		$form = new Form();
		$form->addHidden("id", "plugin:punbb_check");
		$form->addText("content", htmlentities($this->_data->get(), ENT_COMPAT, $this->lang->getEncoding()));
		$form->setSubmit($this->mainLang->get("general", "save"));
		$this->content->output .= $form->html();
		
		// La version officielle
		$this->content->output .= "<h3>".$this->lang->get("home", "latestVersion")."</h3>";
		$this->content->output .= "<p>".$this->_check()."</p>";
	}
	/**
	 * Avertissements
	 */
	public function warning(){
		$latest_version = $this->_check();
		if(!empty($latest_version)){
			$myVersion = $this->_data->get();
			if(version_compare($myVersion, $latest_version, "<")){
				// Titre
				$this->content->output .= "<h3>".$this->lang->get("home", "title")."</h3>";
				
				// Avertissement
				$this->content->output .= "<p>".$this->lang->get("warning", "new_version")." : ".$latest_version."</p>";
			}
		}
	}
	/**
	 * Exécuté tout le temps
	 */
	public function main(){
		parent::main();
		
	}
}
?>